@@ -154,6 +154,8 @@ class HashtagMixin:
         Tuple[List[Media], str]
             List of objects of Media and end_cursor
         """
+        assert tab_key in ("edge_hashtag_to_top_posts", "edge_hashtag_to_media"), \
+            'You must specify one of the options for "tab_key" ("edge_hashtag_to_top_posts" or "edge_hashtag_to_media")'
         unique_set = set()
         medias = []
         while True:
@@ -240,6 +242,8 @@ class HashtagMixin:
         Tuple[List[Media], str]
             List of objects of Media and max_id
         """
+        assert tab_key in ("top", "recent"), \
+            'You must specify one of the options for "tab_key" ("top" or "recent")'
         data = {
             "supported_tabs": dumps([tab_key]),
             # 'lat': 59.8626416,
